==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/OpenAuthenticationAccessPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.OpenAuthenticationAccessPolicyArgs.builder
import com.pulumi.azurenative.logic.kotlin.enums.OpenAuthenticationProviderType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Open authentication access policy defined by user.
 * @property claims The access policy claims.
 * @property type Type of provider for OAuth.
 */
public data class OpenAuthenticationAccessPolicyArgs(
    public val claims: Output<List<OpenAuthenticationPolicyClaimArgs>>? = null,
    public val type: Output<Either<String, OpenAuthenticationProviderType>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.logic.inputs.OpenAuthenticationAccessPolicyArgs> {
    override fun toJava(): com.pulumi.azurenative.logic.inputs.OpenAuthenticationAccessPolicyArgs =
        com.pulumi.azurenative.logic.inputs.OpenAuthenticationAccessPolicyArgs.builder()
            .claims(claims?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [OpenAuthenticationAccessPolicyArgs].
 */
@PulumiTagMarker
public class OpenAuthenticationAccessPolicyArgsBuilder internal constructor() {
    private var claims: Output<List<OpenAuthenticationPolicyClaimArgs>>? = null

    private var type: Output<Either<String, OpenAuthenticationProviderType>>? = null

    /**
     * @param value The access policy claims.
     */
    @JvmName("nxxgdpikpalsmmiq")
    public suspend fun claims(`value`: Output<List<OpenAuthenticationPolicyClaimArgs>>) {
        this.claims = value
    }

    @JvmName("cvhevwhgmttntisr")
    public suspend fun claims(vararg values: Output<OpenAuthenticationPolicyClaimArgs>) {
        this.claims = Output.all(values.asList())
    }

    /**
     * @param values The access policy claims.
     */
    @JvmName("ijbxrotkmgugposc")
    public suspend fun claims(values: List<Output<OpenAuthenticationPolicyClaimArgs>>) {
        this.claims = Output.all(values)
    }

    /**
     * @param value Type of provider for OAuth.
     */
    @JvmName("mjdulirfvsthkcgg")
    public suspend fun type(`value`: Output<Either<String, OpenAuthenticationProviderType>>) {
        this.type = value
    }

    /**
     * @param value The access policy claims.
     */
    @JvmName("qsxkscwseuxpwwhs")
    public suspend fun claims(`value`: List<OpenAuthenticationPolicyClaimArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.claims = mapped
    }

    /**
     * @param argument The access policy claims.
     */
    @JvmName("dlfpeldtivuuyrmn")
    public suspend
    fun claims(argument: List<suspend OpenAuthenticationPolicyClaimArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            OpenAuthenticationPolicyClaimArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.claims = mapped
    }

    /**
     * @param argument The access policy claims.
     */
    @JvmName("ypikrmdoqyuxmbxs")
    public suspend fun claims(
        vararg
        argument: suspend OpenAuthenticationPolicyClaimArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            OpenAuthenticationPolicyClaimArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.claims = mapped
    }

    /**
     * @param argument The access policy claims.
     */
    @JvmName("shglcpyumchdnevl")
    public suspend fun claims(argument: suspend OpenAuthenticationPolicyClaimArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            OpenAuthenticationPolicyClaimArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.claims = mapped
    }

    /**
     * @param values The access policy claims.
     */
    @JvmName("ekwlfffnsurqorpt")
    public suspend fun claims(vararg values: OpenAuthenticationPolicyClaimArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.claims = mapped
    }

    /**
     * @param value Type of provider for OAuth.
     */
    @JvmName("ydcktoplfhdsykxr")
    public suspend fun type(`value`: Either<String, OpenAuthenticationProviderType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Type of provider for OAuth.
     */
    @JvmName("pivfwhmamshosgfi")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, OpenAuthenticationProviderType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Type of provider for OAuth.
     */
    @JvmName("wmslumauftuooleu")
    public fun type(`value`: OpenAuthenticationProviderType) {
        val toBeMapped = Either.ofRight<String, OpenAuthenticationProviderType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): OpenAuthenticationAccessPolicyArgs = OpenAuthenticationAccessPolicyArgs(
        claims = claims,
        type = type,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/OpenAuthenticationAccessPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.OpenAuthenticationAccessPolicyArgs.builder
import com.pulumi.azurenative.logic.kotlin.enums.OpenAuthenticationProviderType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Open authentication access policy defined by user.
 * @property claims The access policy claims.
 * @property type Type of provider for OAuth.
 */
public data class OpenAuthenticationAccessPolicyArgs(
    public val claims: Output<List<OpenAuthenticationPolicyClaimArgs>>? = null,
    public val type: Output<Either<String, OpenAuthenticationProviderType>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.logic.inputs.OpenAuthenticationAccessPolicyArgs> {
    override fun toJava(): com.pulumi.azurenative.logic.inputs.OpenAuthenticationAccessPolicyArgs =
        com.pulumi.azurenative.logic.inputs.OpenAuthenticationAccessPolicyArgs.builder()
            .claims(claims?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [OpenAuthenticationAccessPolicyArgs].
 */
@PulumiTagMarker
public class OpenAuthenticationAccessPolicyArgsBuilder internal constructor() {
    private var claims: Output<List<OpenAuthenticationPolicyClaimArgs>>? = null

    private var type: Output<Either<String, OpenAuthenticationProviderType>>? = null

    /**
     * @param value The access policy claims.
     */
    @JvmName("mmehangkpkkocefu")
    public suspend fun claims(`value`: Output<List<OpenAuthenticationPolicyClaimArgs>>) {
        this.claims = value
    }

    @JvmName("ygehhjeujsduucui")
    public suspend fun claims(vararg values: Output<OpenAuthenticationPolicyClaimArgs>) {
        this.claims = Output.all(values.asList())
    }

    /**
     * @param values The access policy claims.
     */
    @JvmName("hmmrrxftrvbubxmu")
    public suspend fun claims(values: List<Output<OpenAuthenticationPolicyClaimArgs>>) {
        this.claims = Output.all(values)
    }

    /**
     * @param value Type of provider for OAuth.
     */
    @JvmName("kyxoptbxrsvvxcis")
    public suspend fun type(`value`: Output<Either<String, OpenAuthenticationProviderType>>) {
        this.type = value
    }

    /**
     * @param value The access policy claims.
     */
    @JvmName("jduikospuymlmini")
    public suspend fun claims(`value`: List<OpenAuthenticationPolicyClaimArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.claims = mapped
    }

    /**
     * @param argument The access policy claims.
     */
    @JvmName("rgtosyvnrpcttugj")
    public suspend
    fun claims(argument: List<suspend OpenAuthenticationPolicyClaimArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            OpenAuthenticationPolicyClaimArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.claims = mapped
    }

    /**
     * @param argument The access policy claims.
     */
    @JvmName("jouphwuxtimnhlgt")
    public suspend fun claims(
        vararg
        argument: suspend OpenAuthenticationPolicyClaimArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            OpenAuthenticationPolicyClaimArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.claims = mapped
    }

    /**
     * @param argument The access policy claims.
     */
    @JvmName("ojwlymarinjtrvcu")
    public suspend fun claims(argument: suspend OpenAuthenticationPolicyClaimArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            OpenAuthenticationPolicyClaimArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.claims = mapped
    }

    /**
     * @param values The access policy claims.
     */
    @JvmName("wmtyjjvrwibtmspm")
    public suspend fun claims(vararg values: OpenAuthenticationPolicyClaimArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.claims = mapped
    }

    /**
     * @param value Type of provider for OAuth.
     */
    @JvmName("dtlabomlpjniafur")
    public suspend fun type(`value`: Either<String, OpenAuthenticationProviderType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Type of provider for OAuth.
     */
    @JvmName("gvhualjqeeasaunq")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, OpenAuthenticationProviderType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Type of provider for OAuth.
     */
    @JvmName("mjtnmesljcvlwdik")
    public fun type(`value`: OpenAuthenticationProviderType) {
        val toBeMapped = Either.ofRight<String, OpenAuthenticationProviderType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): OpenAuthenticationAccessPolicyArgs = OpenAuthenticationAccessPolicyArgs(
        claims = claims,
        type = type,
    )
}
